==> webkit2gtk_2.44.3.orig.tar.xz: webkitgtk-2.44.3/Source/WebCore/loader/ApplicationManifestLoader.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(APPLICATION_MANIFEST)

#include "ApplicationManifest.h"
#include "CachedRawResourceClient.h"
#include "CachedResourceHandle.h"
#include "LoaderMalloc.h"
#include <wtf/CheckedRef.h>
#include <wtf/Noncopyable.h>
#include <wtf/URL.h>

namespace WebCore {

class CachedApplicationManifest;
class DocumentLoader;

class ApplicationManifestLoader final : private CachedRawResourceClient {
WTF_MAKE_NONCOPYABLE(ApplicationManifestLoader); WTF_MAKE_FAST_ALLOCATED_WITH_HEAP_IDENTIFIER(Loader);
public:
    typedef Function<void (CachedResourceHandle<CachedApplicationManifest>)> CompletionHandlerType;

    ApplicationManifestLoader(DocumentLoader&, const URL&, bool);
    virtual ~ApplicationManifestLoader();

    bool startLoading();
    void stopLoading();

    std::optional<ApplicationManifest>& processManifest();

private:
    void notifyFinished(CachedResource&, const NetworkLoadMetrics&);

    SingleThreadWeakRef<DocumentLoader> m_documentLoader;
    std::optional<ApplicationManifest> m_processedManifest;
    URL m_url;
    bool m_useCredentials;
    CachedResourceHandle<CachedApplicationManifest> m_resource;
};

} // namespace WebCore

#endif // ENABLE(APPLICATION_MANIFEST)

==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/WebCore/loader/ApplicationManifestLoader.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(APPLICATION_MANIFEST)

#include "ApplicationManifest.h"
#include "CachedRawResourceClient.h"
#include "CachedResourceHandle.h"
#include "LoaderMalloc.h"
#include <wtf/CheckedRef.h>
#include <wtf/Noncopyable.h>
#include <wtf/URL.h>

namespace WebCore {

class CachedApplicationManifest;
class DocumentLoader;

class ApplicationManifestLoader final : private CachedRawResourceClient {
WTF_MAKE_NONCOPYABLE(ApplicationManifestLoader); WTF_MAKE_FAST_ALLOCATED_WITH_HEAP_IDENTIFIER(Loader);
public:
    typedef Function<void (CachedResourceHandle<CachedApplicationManifest>)> CompletionHandlerType;

    ApplicationManifestLoader(DocumentLoader&, const URL&, bool);
    virtual ~ApplicationManifestLoader();

    bool startLoading();
    void stopLoading();

    std::optional<ApplicationManifest>& processManifest();

private:
    void notifyFinished(CachedResource&, const NetworkLoadMetrics&, LoadWillContinueInAnotherProcess);

    SingleThreadWeakRef<DocumentLoader> m_documentLoader;
    std::optional<ApplicationManifest> m_processedManifest;
    URL m_url;
    bool m_useCredentials;
    CachedResourceHandle<CachedApplicationManifest> m_resource;
};

} // namespace WebCore

#endif // ENABLE(APPLICATION_MANIFEST)
